@@ -8,7 +8,7 @@ package Log::Dispatch::Email::MailSender;
 use strict;
 use warnings;
 
-our $VERSION = '2.54';
+our $VERSION = '2.58';
 
 use Log::Dispatch::Email;
 
@@ -52,7 +52,7 @@ sub send_email {
     my $self = shift;
     my %p    = @_;
 
-    local $?;
+    local ( $?, $@, $SIG{__DIE__} );
     eval {
         my $sender = Mail::Sender->new(
             {
@@ -90,13 +90,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatch::Email::MailSender - Subclass of Log::Dispatch::Email that uses the Mail::Sender module
 
 =head1 VERSION
 
-version 2.54
+version 2.58
 
 =head1 SYNOPSIS
 
@@ -168,6 +170,12 @@ The reply-to address.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/houseabsolute/Log-Dispatch/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
