@@ -1,8 +1,10 @@
 package Log::Dispatch::Syslog;
-$Log::Dispatch::Syslog::VERSION = '2.44';
+
 use strict;
 use warnings;
 
+our $VERSION = '2.58';
+
 use Log::Dispatch::Output;
 
 use base qw( Log::Dispatch::Output );
@@ -29,6 +31,9 @@ sub new {
 
 my ($Ident) = $0 =~ /(.+)/;
 
+my $thread_lock;
+my $threads_loaded;
+
 sub _init {
     my $self = shift;
 
@@ -59,8 +64,15 @@ sub _init {
 
     $self->{$_} = $p{$_} for qw( ident logopt facility socket lock );
     if ( $self->{lock} ) {
-        require threads;
-        require threads::shared;
+
+        unless ($threads_loaded) {
+            local ( $@, $SIG{__DIE__} );
+
+            # These need to be loaded with use, not require.
+            eval 'use threads; use threads::shared';
+            $threads_loaded = 1;
+        }
+        &threads::shared::share( \$thread_lock );
     }
 
     $self->{priorities} = [
@@ -75,8 +87,6 @@ sub _init {
     ];
 }
 
-my $thread_lock : shared = 0;
-
 sub log_message {
     my $self = shift;
     my %p    = @_;
@@ -85,6 +95,7 @@ sub log_message {
 
     lock($thread_lock) if $self->{lock};
 
+    local ( $@, $SIG{__DIE__} );
     eval {
         if ( defined $self->{socket} ) {
             Sys::Syslog::setlogsock(
@@ -122,7 +133,7 @@ Log::Dispatch::Syslog - Object for logging to system log.
 
 =head1 VERSION
 
-version 2.44
+version 2.58
 
 =head1 SYNOPSIS
 
@@ -205,13 +216,19 @@ This defaults to false.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/houseabsolute/Log-Dispatch/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
